/* $Id $
	------------------------------------------------------------------
	Copyright (C) 2013 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
*/
'use strict';

var Directories = function()
{
	var directories = {};
	
	/**
		Initialize the page.
	*/
	directories.initPage = function()
	{
		var pageId = Doc.getPageId();		
		if (pageId == 'edit-page')
		{
			// Save + Close buttons
			Buttons.addClickHandler('btnSave', directories.save);
			Buttons.addClickHandler('close', App.closeWindow);
			
			// Tab validation
			TabControl.addTabValidator('settings.info', directories.validateDirectory);
		}
		else if (pageId == 'list-page')
		{
			IconStore.addDefaultIcons();
			IconStore.addIconSet('Search', 'search.png', 'search-selected.png');
			IconStore.addIconSet('FolderCompressed', 'folder-compressed.png', 'folder-compressed-selected.png');
			IconStore.addIconSet('FolderDeleted', 'folder-deleted.png');

			Events.addEventHandler('joust', 'joust-select', directories.onSelect);
			Events.addEventHandler('joust', 'joust-lazy-init', directories.lazyInit);
			
			Joust2.draw('joust');
			
			Buttons.addClickHandler('btnSearch', directories.searchOnClick);
			Buttons.addClickHandler('btnRefresh', directories.refresh);
			Buttons.addClickHandler('btnNewDirectory', directories.newDirectory);
			Buttons.addClickHandler('close', App.closeWindow);
			Buttons.addClickHandler('btnOk', directories.returnSelected);
			
			Joust2.select(Data.get('page-data', 'initial-directory'), !Data.int('page-data', 'sync-with-directory'));
		}
	}
	
	directories.validateDirectory = function()
	{
		var frm = document.forms['directory'];
		if (Strings.trim(frm.name.value) == '')
		{
			Forms.showNotification(frm.name, 'You must enter a name');
			return false;
		}
		return true;
	}
	
	// Submit the form
	directories.save = function()
	{
		var frm = document.forms['directory'];
		if (TabControl.validateActiveTab('settings'))
		{
			frm.submit();
		}
	}
	
	/**
		Handles click event in the directory tree.
	*/
	directories.onSelect = function(event)
	{
		var menuElement = event.target;
		var menuItem = menuElement.item;

		var mode = Data.get('page-data', 'mode');
		if (mode == 'selectonedirectory')
		{
			var frm = document.forms['directory'];
			frm.directory_id.value = menuItem.id;
			frm.path.value = menuItem.path;
			//lastDirectoryId = directoryId;
		}
		else
		{
			if (menuElement.id == 'search')
			{
				var url = '../files/index.jsp?ID='+App.getSessionId();
				url += '&cmd=Search&subcontext=search';
				url += '&mode='+Data.get('page-data', 'mode');
				parent.frames['files'].location.href = url;
			}
			else
			{
				var url = '../files/index.jsp?ID='+App.getSessionId();
				url += '&cmd=List&directory_id='+menuElement.id;
				url += '&mode='+Data.get('page-data', 'mode');
				parent.frames['files'].location.href = url;
			}
		}
	}
	
	
	/**
		Lazy loading of subdirectories
	*/
	directories.lazyInit = function(event)
	{
		var menuElement = event.target;
		Doc.addClass(menuElement, 'working');
		try
		{
			var request = Ajax.getXmlHttpRequest();
			var url = 'ajax.jsp?ID='+App.getSessionId();
			url += '&cmd=GetSubdirectories&item_id=' + menuElement.id;
			request.open("GET", url, false);
			request.send(null);
			
			var response = JSON.parse(request.responseText);
			if (response.status != 'ok')
			{
				Forms.showNotification(menuElement.id+'-outline', response.message);
			}
			
			Joust2.addChildren(menuElement, response.subdirs || []);
			Joust2.toggle(menuElement);
		}
		finally
		{
			Doc.removeClass(menuElement, 'working');
		}
	}
	
	directories.searchOnClick = function()
	{
		Doc.show('search');
		Joust2.select('search');
	}

	
	directories.updateSearchResults = function(files, directories)
	{
		var searchResults = Doc.element('search-text');
		if (searchResults)
		{
			searchResults.innerHTML = 'Search results (' + (files + directories) + ')';
		}

	}
	directories.refresh = function()
	{
		location.reload();
	}

	directories.synchronizeTo = function(directoryId, parentId)
	{
		var menuElement = Doc.element(directoryId);
		if (!menuElement && parentId)
		{
			var parentElement = Doc.element(parentId);
			if (parentElement && parentElement.item.isLazy)
			{
				Joust2.toggle(parentElement);
				menuElement = Doc.element(directoryId);
			}
		}
		
		if (!menuElement)
		{
			var url = '../directories/index.jsp?ID='+App.getSessionId();
			url += '&cmd=ViewItem&item_id='+directoryId;
			url += '&mode='+Data.get('page-data', 'mode');
			parent.parent.location.href = url;
			
		}
		else
		{
			Joust2.select(menuElement);
		}
	}

	directories.newDirectory = function()
	{
		var frm = document.forms['directory'];
		Items.newItem('DIRECTORY', '&parent_id='+frm.directory_id.value);
	}

	
	directories.returnSelected = function()
	{
		var frm = document.forms['directory'];
		var callback = frm.callback.value;
		var notifyTarget = window.opener.document.getElementById(callback);
		var callbackMethod = window.opener[callback];

		if (notifyTarget)
		{
			// Send event to the target in the opener window
			Events.sendCustomEvent(notifyTarget, 'base-selected', {'id': frm.directory_id.value, 'name': frm.path.value, 'itemType': 'DIRECTORY'});
		}
		else if (callbackMethod)
		{
			// Call the callback method in the opener window
			callbackMethod.call(null, frm.directory_id.value, frm.path.value);
		}
		App.closeWindow();
	}

	
	return directories;
}();

Doc.onLoad(Directories.initPage);
