/* $Id $
	------------------------------------------------------------------
	Copyright (C) 2013 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
*/
'use strict';

var PlateTypes = function()
{
	var plateTypes = {};
	
	/**
		Initialize the page.
	*/
	plateTypes.initPage = function()
	{
		var pageId = Doc.getPageId();
		if (pageId == 'edit-page')
		{
			// Save + Close buttons
			Buttons.addClickHandler('btnSave', plateTypes.save);
			Buttons.addClickHandler('close', App.closeWindow);

			// Tab validation
			TabControl.addTabValidator('settings.info', plateTypes.validatePlateType);
		}
		else if (pageId == 'view-page')
		{
			var itemId = Data.get('page-data', 'item-id');
			var attributes = {'item-type': 'PLATETYPE', 'item-id': itemId};
			Buttons.addClickHandler('btnEdit', Buttons.editItem, attributes);
			Buttons.addClickHandler('btnDelete', Buttons.deleteItem, attributes);
			Buttons.addClickHandler('btnRestore', Buttons.restoreItem, attributes);
			Buttons.addClickHandler('btnUsingItems', Buttons.showUsingItems, attributes);
			Buttons.addClickHandler('btnDeletePermanently', Buttons.deleteItemPermanently, attributes);
			Buttons.addClickHandler('btnShare', Buttons.shareItem, attributes);
			Buttons.addClickHandler('btnSetOwner', Buttons.setOwner, attributes);
			Buttons.addClickHandler('btnExport', Buttons.runPlugin, attributes);
			Buttons.addClickHandler('btnImport', Buttons.runPlugin, attributes);
			Buttons.addClickHandler('btnRunPlugin', Buttons.runPlugin, attributes);
			
			TabControl.addTabActivateListener('main.events', plateTypes.viewEventTypes);
		}
		else if (pageId == 'list-page')
		{
			var attributes = {'item-type': 'PLATETYPE'};
			var tableAttributes = {'table-id': 'platetypes'};
			Buttons.addClickHandler('btnNewItem', Buttons.newItem, attributes);
			Buttons.addClickHandler('btnDeleteItems', Buttons.deleteItems, tableAttributes);
			Buttons.addClickHandler('btnRestoreItems', Buttons.restoreItems, tableAttributes);
			Buttons.addClickHandler('btnShareItems', Buttons.shareItems, tableAttributes);
			Buttons.addClickHandler('btnSetOwner', Buttons.setOwnerOfItems, tableAttributes);
			Buttons.addClickHandler('btnColumns', Buttons.configureColumns, tableAttributes);
			Buttons.addClickHandler('btnExport', Buttons.runListPlugin, tableAttributes);
			Buttons.addClickHandler('btnImport', Buttons.runListPlugin, tableAttributes);
			Buttons.addClickHandler('btnRunPlugin', Buttons.runListPlugin, tableAttributes);
			
			Buttons.addClickHandler('close', App.closeWindow);
			Buttons.addClickHandler('btnOk', Buttons.returnSelected, tableAttributes);
		}
	}

	plateTypes.viewEventTypes = function()
	{
		var plateTypeId = Data.get('page-data', 'item-id');
		var url = 'eventtypes/index.jsp?ID='+App.getSessionId();
		url += '&cmd=List&platetype_id='+plateTypeId;
		location.replace(url);
	}
	
	plateTypes.validatePlateType = function()
	{
		var frm = document.forms['platetype'];
		if (Strings.trim(frm.name.value) == '')
		{
			Forms.showNotification(frm.name, 'You must enter a name');
			return false;
		}
		return true;
	}

	// Submit the form
	plateTypes.save = function()
	{
		var frm = document.forms['platetype'];
		if (TabControl.validateActiveTab('settings'))
		{
			frm.submit();
		}
	}

	return plateTypes;
}();

Doc.onLoad(PlateTypes.initPage);
